@@ -17,7 +17,7 @@
 #' Add a column with the individual birth date
 #'
 #' @param x Table in the cdm that contains 'person_id' or 'subject_id'
-#' @param cdm 'cdm' object created with CDMConnector::cdm_from_con().
+#' @param cdm A cdm_reference object.
 #' @param name Name of the column to be added with the date of birth
 #' @param missingDay Day of the individuals with no or imposed day of birth
 #' @param missingMonth Month of the individuals with no or imposed month of
@@ -38,16 +38,20 @@
 #'   addDateOfBirth()
 #' }
 addDateOfBirth <- function(x,
-                           cdm = attr(x, "cdm_reference"),
+                           cdm = lifecycle::deprecated(),
                            name = "date_of_birth",
                            missingDay = 1,
                            missingMonth = 1,
                            imposeDay = FALSE,
                            imposeMonth = FALSE) {
+  if (lifecycle::is_present(cdm)) {
+    lifecycle::deprecate_warn("0.6.0", "addDateOfBirth(cdm)")
+  }
   # initial checks
   # checkInputs(
   #   x, cdm, name, misisngDay, missingMonth, imposeDay, imposeMonth
   # )
+  cdm <- omopgenerics::cdmReference(x)
 
   personVariable <- checkX(x)
 
