@@ -32,9 +32,11 @@
 #' will be considered as missing for all the individuals.
 #' @param ageImposeDay TRUE or FALSE. Whether the day of the date of birth
 #' will be considered as missing for all the individuals.
-#' @param ageGroup if not NULL, a list of ageGroup vectors
+#' @param ageGroup if not NULL, a list of ageGroup vectors.
+#' @param missingAgeGroupValue Value to include if missing age.
 #' @param sex TRUE or FALSE. If TRUE, sex will be identified
 #' @param sexName Sex variable name
+#' @param missingSexValue Value to include if missing sex.
 #' @param priorObservation TRUE or FALSE. If TRUE, days of between the start
 #' of the current observation period and the indexDate will be calculated
 #' @param priorObservationName Prior observation variable name
@@ -50,11 +52,12 @@
 #' \donttest{
 #' library(PatientProfiles)
 #' cdm <- mockPatientProfiles()
-#' cdm$cohort1 %>% addDemographics(cdm)
+#' cdm$cohort1 %>%
+#'   addDemographics()
 #' }
 #'
 addDemographics <- function(x,
-                            cdm = attr(x, "cdm_reference"),
+                            cdm = lifecycle::deprecated(),
                             indexDate = "cohort_start_date",
                             age = TRUE,
                             ageName = "age",
@@ -63,13 +66,19 @@ addDemographics <- function(x,
                             ageImposeMonth = FALSE,
                             ageImposeDay = FALSE,
                             ageGroup = NULL,
+                            missingAgeGroupValue = "None",
                             sex = TRUE,
                             sexName = "sex",
+                            missingSexValue = "None",
                             priorObservation = TRUE,
                             priorObservationName = "prior_observation",
                             futureObservation = TRUE,
                             futureObservationName = "future_observation") {
   ## change ageDefaultMonth, ageDefaultDay to integer
+  if (lifecycle::is_present(cdm)) {
+    lifecycle::deprecate_warn("0.6.0", "addDemographics(cdm)")
+  }
+  cdm <- omopgenerics::cdmReference(x)
 
   if (typeof(ageDefaultMonth) == "character") {
     ageDefaultMonth <- as.integer(ageDefaultMonth)
@@ -103,25 +112,29 @@ addDemographics <- function(x,
   if (!(age | sex | priorObservation | futureObservation)) {
     cli::cli_abort("age, sex, priorObservation, futureObservation can not be FALSE")
   }
+  checkmate::assertCharacter(missingAgeGroupValue, len = 1, any.missing = FALSE)
+  checkmate::assertCharacter(missingSexValue, len = 1, any.missing = FALSE)
 
   # check variable names
+  name <- character()
   if (age) {
     ageName <- checkSnakeCase(ageName)
+    name <- c(name, ageName)
   }
   if (sex) {
     sexName <- checkSnakeCase(sexName)
+    name <- c(name, sexName)
   }
   if (priorObservation) {
     priorObservationName <- checkSnakeCase(priorObservationName)
+    name <- c(name, priorObservationName)
   }
   if (futureObservation) {
     futureObservationName <- checkSnakeCase(futureObservationName)
+    name <- c(name, futureObservationName)
   }
 
-  checkNewName(ageName, x)
-  checkNewName(sexName, x)
-  checkNewName(priorObservationName, x)
-  checkNewName(futureObservationName, x)
+  checkNewName(name = name, x = x)
 
   if (age == TRUE || priorObservation == TRUE || futureObservation == TRUE) {
     checkmate::assert_true(
@@ -212,7 +225,7 @@ addDemographics <- function(x,
   }
 
   if (sex == TRUE) {
-    sQ <- sexQuery(name = sexName)
+    sQ <- sexQuery(name = sexName, missingValue = missingSexValue)
   } else {
     sQ <- NULL
   }
@@ -255,21 +268,17 @@ addDemographics <- function(x,
       ))
   }
 
-  x <- x %>%
-    CDMConnector::computeQuery()
+  x <- x %>% dplyr::compute()
 
   if (!is.null(ageGroup)) {
     x <- addCategories(
       x = x,
       variable = ageName,
       categories = ageGroup,
-      missingCategoryValue = "None"
+      missingCategoryValue = missingAgeGroupValue
     )
   }
 
-  # put back the initial attributes to the output tibble
-  x <- x %>% addAttributes(startTibble)
-
   return(x)
 }
 
@@ -287,11 +296,11 @@ ageQuery <- function(indexDate, name) {
     rlang::set_names(glue::glue(name)))
 }
 
-sexQuery <- function(name) {
+sexQuery <- function(name, missingValue) {
   return(glue::glue('dplyr::case_when(
       .data$gender_concept_id == 8507 ~ "Male",
       .data$gender_concept_id == 8532 ~ "Female",
-      TRUE ~ as.character(NA))') %>%
+      TRUE ~ "{missingValue}")') %>%
     rlang::parse_exprs() %>%
     rlang::set_names(glue::glue(name)))
 }
@@ -313,8 +322,7 @@ futureObservationQuery <- function(indexDate, name) {
 #' Compute the age of the individuals at a certain date
 #'
 #' @param x Table with individuals in the cdm.
-#' @param cdm Object that contains a cdm reference. Use CDMConnector to obtain a
-#' cdm reference.
+#' @param cdm A cdm_reference object.
 #' @param indexDate Variable in x that contains the date to compute the age.
 #' @param ageName Name of the new column that contains age.
 #' @param ageGroup List of age groups to be added.
@@ -326,48 +334,33 @@ futureObservationQuery <- function(indexDate, name) {
 #' considered as missing for all the individuals.
 #' @param ageImposeDay Whether the day of the date of birth will be considered
 #' as missing for all the individuals.
+#' @param missingAgeGroupValue Value to include if missing age.
 #'
 #' @return tibble with the age column added
 #' @export
 #'
 #' @examples
 #' \donttest{
-#' library(DBI)
-#' library(duckdb)
-#' library(PatientProfiles)
-#' cohort1 <- dplyr::tibble(
-#'   cohort_definition_id = c("1", "1", "1"),
-#'   subject_id = c("1", "2", "3"),
-#'   cohort_start_date = c(
-#'     as.Date("2010-01-01"), as.Date("2010-01-01"), as.Date("2010-01-01")
-#'   ),
-#'   cohort_end_date = c(
-#'     as.Date("2015-01-01"), as.Date("2013-01-01"), as.Date("2018-01-01")
-#'   )
-#' )
+#' cdm <- mockPatientProfiles()
 #'
-#' person <- dplyr::tibble(
-#'   person_id = c("1", "2", "3"),
-#'   gender_concept_id = c("8507", "8532", "8507"),
-#'   year_of_birth = c(2000, 1995, NA),
-#'   month_of_birth = c(NA, 07, 08),
-#'   day_of_birth = c(01, 25, 03)
-#' )
-#' cdm <- mockPatientProfiles(person = person, cohort1 = cohort1)
-#' addAge(x = cdm[["cohort1"]], cdm = cdm)
+#' cdm$cohort1 |>
+#'   addAge()
 #' }
 addAge <- function(x,
-                   cdm = attr(x, "cdm_reference"),
+                   cdm = lifecycle::deprecated(),
                    indexDate = "cohort_start_date",
                    ageName = "age",
                    ageGroup = NULL,
                    ageDefaultMonth = 1,
                    ageDefaultDay = 1,
                    ageImposeMonth = FALSE,
-                   ageImposeDay = FALSE) {
+                   ageImposeDay = FALSE,
+                   missingAgeGroupValue = "None") {
+  if (lifecycle::is_present(cdm)) {
+    lifecycle::deprecate_warn("0.6.0", "addAge(cdm)")
+  }
   x <- x %>%
     addDemographics(
-      cdm = cdm,
       indexDate = indexDate,
       age = TRUE,
       ageName = ageName,
@@ -376,6 +369,7 @@ addAge <- function(x,
       ageDefaultMonth = ageDefaultMonth,
       ageImposeDay = ageImposeDay,
       ageImposeMonth = ageImposeMonth,
+      missingAgeGroupValue = missingAgeGroupValue,
       sex = FALSE,
       priorObservation = FALSE,
       futureObservation = FALSE,
@@ -391,8 +385,7 @@ addAge <- function(x,
 #' certain date
 #'
 #' @param x Table with individuals in the cdm.
-#' @param cdm Object that contains a cdm reference. Use CDMConnector to obtain a
-#' cdm reference.
+#' @param cdm A cdm_reference object.
 #' @param indexDate Variable in x that contains the date to compute the future
 #' observation.
 #' @param futureObservationName name of the new column to be added
@@ -403,55 +396,20 @@ addAge <- function(x,
 #'
 #' @examples
 #' \donttest{
-#' library(DBI)
-#' library(duckdb)
-#' library(PatientProfiles)
-#' cohort1 <- dplyr::tibble(
-#'   cohort_definition_id = c("1", "1", "1"),
-#'   subject_id = c("1", "2", "3"),
-#'   cohort_start_date = c(
-#'     as.Date("2010-03-03"),
-#'     as.Date("2010-03-01"),
-#'     as.Date("2010-02-01")
-#'   ),
-#'   cohort_end_date = c(
-#'     as.Date("2015-01-01"),
-#'     as.Date("2013-01-01"),
-#'     as.Date("2013-01-01")
-#'   )
-#' )
+#' cdm <- mockPatientProfiles()
 #'
-#' obs_1 <- dplyr::tibble(
-#'   observation_period_id = c("1", "2", "3"),
-#'   person_id = c("1", "2", "3"),
-#'   observation_period_start_date = c(
-#'     as.Date("2010-02-03"),
-#'     as.Date("2010-02-01"),
-#'     as.Date("2010-01-01")
-#'   ),
-#'   observation_period_end_date = c(
-#'     as.Date("2014-01-01"),
-#'     as.Date("2012-01-01"),
-#'     as.Date("2012-01-01")
-#'   )
-#' )
-#'
-#' cdm <-
-#'   mockPatientProfiles(
-#'     seed = 1,
-#'     cohort1 = cohort1,
-#'     observation_period = obs_1
-#'   )
-#'
-#' result <- cdm$cohort1 %>% addFutureObservation(cdm)
+#' cdm$cohort1 %>%
+#'   addFutureObservation()
 #' }
 addFutureObservation <- function(x,
-                                 cdm = attr(x, "cdm_reference"),
+                                 cdm = lifecycle::deprecated(),
                                  indexDate = "cohort_start_date",
                                  futureObservationName = "future_observation") {
+  if (lifecycle::is_present(cdm)) {
+    lifecycle::deprecate_warn("0.6.0", "addFutureObservation(cdm)")
+  }
   x <- x %>%
     addDemographics(
-      cdm = cdm,
       indexDate = indexDate,
       age = FALSE,
       ageGroup = NULL,
@@ -475,8 +433,7 @@ addFutureObservation <- function(x,
 #' at a certain date
 #'
 #' @param x Table with individuals in the cdm
-#' @param cdm Object that contains a cdm reference. Use CDMConnector to obtain a
-#' cdm reference.
+#' @param cdm A cdm_reference object.
 #' @param indexDate Variable in x that contains the date to compute the prior
 #' observation.
 #' @param priorObservationName name of the new column to be added
@@ -487,55 +444,20 @@ addFutureObservation <- function(x,
 #'
 #' @examples
 #' \donttest{
-#' library(DBI)
-#' library(duckdb)
-#' library(PatientProfiles)
-#' cohort1 <- dplyr::tibble(
-#'   cohort_definition_id = c("1", "1", "1"),
-#'   subject_id = c("1", "2", "3"),
-#'   cohort_start_date = c(
-#'     as.Date("2010-03-03"),
-#'     as.Date("2010-03-01"),
-#'     as.Date("2010-02-01")
-#'   ),
-#'   cohort_end_date = c(
-#'     as.Date("2015-01-01"),
-#'     as.Date("2013-01-01"),
-#'     as.Date("2013-01-01")
-#'   )
-#' )
+#' cdm <- mockPatientProfiles()
 #'
-#' obs_1 <- dplyr::tibble(
-#'   observation_period_id = c("1", "2", "3"),
-#'   person_id = c("1", "2", "3"),
-#'   observation_period_start_date = c(
-#'     as.Date("2010-02-03"),
-#'     as.Date("2010-02-01"),
-#'     as.Date("2010-01-01")
-#'   ),
-#'   observation_period_end_date = c(
-#'     as.Date("2014-01-01"),
-#'     as.Date("2012-01-01"),
-#'     as.Date("2012-01-01")
-#'   )
-#' )
-#'
-#' cdm <-
-#'   mockPatientProfiles(
-#'     seed = 1,
-#'     cohort1 = cohort1,
-#'     observation_period = obs_1
-#'   )
-#'
-#' result <- cdm$cohort1 %>% addPriorObservation(cdm)
+#' cdm$cohort1 %>%
+#'   addPriorObservation()
 #' }
 addPriorObservation <- function(x,
-                                cdm = attr(x, "cdm_reference"),
+                                cdm = lifecycle::deprecated(),
                                 indexDate = "cohort_start_date",
                                 priorObservationName = "prior_observation") {
+  if (lifecycle::is_present(cdm)) {
+    lifecycle::deprecate_warn("0.6.0", "addPriorObservation(cdm)")
+  }
   x <- x %>%
     addDemographics(
-      cdm = cdm,
       indexDate = indexDate,
       age = FALSE,
       ageGroup = NULL,
@@ -558,8 +480,7 @@ addPriorObservation <- function(x,
 #' Indicate if a certain record is within the observation period
 #'
 #' @param x Table with individuals in the cdm.
-#' @param cdm Object that contains a cdm reference. Use CDMConnector to obtain a
-#' cdm reference.
+#' @param cdm A cdm_reference object.
 #' @param indexDate Variable in x that contains the date to compute the
 #' observation flag.
 #' @param name name of the column to hold the result of the query:
@@ -570,16 +491,20 @@ addPriorObservation <- function(x,
 #'
 #' @examples
 #' \donttest{
-#' library(PatientProfiles)
 #' cdm <- mockPatientProfiles()
-#' cdm$cohort1 %>% addInObservation(cdm)
+#' cdm$cohort1 %>%
+#'   addInObservation()
 #' }
 #'
 addInObservation <- function(x,
-                             cdm = attr(x, "cdm_reference"),
+                             cdm = lifecycle::deprecated(),
                              indexDate = "cohort_start_date",
                              name = "in_observation") {
+  if (lifecycle::is_present(cdm)) {
+    lifecycle::deprecate_warn("0.6.0", "inObservation(cdm)")
+  }
   ## check for standard types of user error
+  cdm <- omopgenerics::cdmReference(x)
   personVariable <- checkX(x)
   checkCdm(cdm, c("observation_period"))
   checkVariableInX(indexDate, x)
@@ -591,7 +516,6 @@ addInObservation <- function(x,
 
   x <- x %>%
     addDemographics(
-      cdm = cdm,
       indexDate = indexDate,
       age = FALSE,
       sex = FALSE,
@@ -607,8 +531,7 @@ addInObservation <- function(x,
       -"prior_observation", -"future_observation"
     )
 
-  x <- x %>%
-    CDMConnector::computeQuery()
+  x <- x %>% dplyr::compute()
 
   return(x)
 }
@@ -616,26 +539,29 @@ addInObservation <- function(x,
 #' Compute the sex of the individuals
 #'
 #' @param x Table with individuals in the cdm
-#' @param cdm Object that contains a cdm reference. Use CDMConnector to obtain a
-#' cdm reference.
-#' @param sexName name of the new column to be added
+#' @param cdm A cdm_reference object.
+#' @param sexName name of the new column to be added.
+#' @param missingSexValue Value to include if missing sex.
 #'
 #' @return table x with the added column with sex information
 #' @export
 #'
 #' @examples
 #' \donttest{
-#' library(PatientProfiles)
 #' cdm <- mockPatientProfiles()
-#' cdm$cohort1 %>% addSex(cdm)
+#' cdm$cohort1 %>%
+#'   addSex()
 #' }
 #'
 addSex <- function(x,
-                   cdm = attr(x, "cdm_reference"),
-                   sexName = "sex") {
+                   cdm = lifecycle::deprecated(),
+                   sexName = "sex",
+                   missingSexValue = "None") {
+  if (lifecycle::is_present(cdm)) {
+    lifecycle::deprecate_warn("0.6.0", "addSex(cdm)")
+  }
   x <- x %>%
     addDemographics(
-      cdm = cdm,
       indexDate = NULL,
       age = FALSE,
       ageGroup = NULL,
@@ -645,6 +571,7 @@ addSex <- function(x,
       ageImposeMonth = FALSE,
       sex = TRUE,
       sexName = sexName,
+      missingSexValue = missingSexValue,
       priorObservation = FALSE,
       futureObservation = FALSE,
       ageName = NULL,
