@@ -1,18 +1,3 @@
-test_that("test checkX: subject_id and person_id", {
-  cohort3 <- dplyr::tibble(
-    cohort_definition_id = c(1, 1),
-    subject_id = c(1, 1),
-    person_id = c(1, 1),
-    cohort_start_date = as.Date(
-      c("2020-01-01", "2020-01-15")
-    ),
-    cohort_end_date = as.Date(
-      c("2020-01-01", "2020-01-15")
-    )
-  )
-  expect_error(cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort3))
-})
-
 
 test_that("test checkCategory with length 1 ", {
   person <- dplyr::tibble(
@@ -20,7 +5,9 @@ test_that("test checkCategory with length 1 ", {
     gender_concept_id = 1,
     year_of_birth = c(1980, 1950),
     month_of_birth = 01,
-    day_of_birth = 01
+    day_of_birth = 01,
+    race_concept_id = 0,
+    ethnicity_concept_id = 0
   )
 
   cohort1 <- dplyr::tibble(
@@ -34,12 +21,23 @@ test_that("test checkCategory with length 1 ", {
     )
   )
 
-  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, person = person)
+  op <- dplyr::tibble(
+    person_id = 1:2,
+    observation_period_id = 1:2,
+    observation_period_start_date = as.Date("2000-01-01"),
+    observation_period_end_date = as.Date("2030-01-01"),
+    period_type_concept_id = 0
+  )
+
+  cdm <- mockPatientProfiles(
+    connectionDetails = connectionDetails, cohort1 = cohort1, person = person,
+    observation_period = op
+  )
 
   categories <- list("age_group" = list(c(0, 69), c(70)))
 
   a <- cdm$cohort1 %>%
-    addAge(cdm, indexDate = "cohort_start_date") %>%
+    addAge(indexDate = "cohort_start_date") %>%
     addCategories("age", categories) %>%
     dplyr::collect()
   expect_true(a[a$subject_id == 2, ]$age_group == "70 to 70")
@@ -48,7 +46,7 @@ test_that("test checkCategory with length 1 ", {
 
   categories <- list("age_group" = list(c(69, 0), c(70)))
 
-  expect_error(cdm$cohort1 %>% addAge(cdm, indexDate = "cohort_start_date") %>%
+  expect_error(cdm$cohort1 %>% addAge(indexDate = "cohort_start_date") %>%
     addCategories("age", categories))
 })
 
@@ -70,13 +68,38 @@ test_that(" test checkNewName renames duplicate column names in addInObservation
     ),
     flag = c(0, 0)
   )
-  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1)
-
-  expect_warning(x <- addInObservation(cdm$cohort1, cdm, name = "flag"))
-  expect_true(all(c("flag", "flag_1") %in% colnames(x)))
-  expect_true(all(c("flag", "flag_new") %in% colnames(addInObservation(cdm$cohort1, cdm, name = "flag_new"))))
+  person <- dplyr::tibble(
+    person_id = c(1, 2),
+    gender_concept_id = 1,
+    year_of_birth = c(1980, 1950),
+    month_of_birth = 01,
+    day_of_birth = 01,
+    race_concept_id = 0,
+    ethnicity_concept_id = 0
+  )
+  op <- dplyr::tibble(
+    person_id = 1:2,
+    observation_period_id = 1:2,
+    observation_period_start_date = as.Date("2000-01-01"),
+    observation_period_end_date = as.Date("2030-01-01"),
+    period_type_concept_id = 0
+  )
 
+  cdm <- mockPatientProfiles(
+    connectionDetails = connectionDetails, cohort1 = cohort1, person = person,
+    observation_period = op
+  )
 
+  expect_warning(x <- addInObservation(cdm$cohort1, name = "flag"))
+  expect_true(all(c(
+    "cohort_definition_id", "subject_id", "cohort_start_date",
+    "cohort_end_date", "flag"
+  ) == colnames(x)))
+  y <- addInObservation(cdm$cohort1, name = "flag_new")
+  expect_true(all(c(
+    "cohort_definition_id", "subject_id", "cohort_start_date",
+    "cohort_end_date", "flag", "flag_new"
+  ) == colnames(y)))
 
   cohort1 <- dplyr::tibble(
     cohort_definition_id = c(1, 1),
@@ -96,24 +119,39 @@ test_that(" test checkNewName renames duplicate column names in addInObservation
     flag = c(0, 0),
     flag_1 = c(0, 0)
   )
-  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1)
+  cdm <- mockPatientProfiles(
+    connectionDetails = connectionDetails, cohort1 = cohort1, person = person,
+    observation_period = op
+  )
+
+  expect_warning(x <- addInObservation(cdm$cohort1, name = "flag"))
+  expect_true(all(c(
+    "cohort_definition_id", "subject_id", "cohort_start_date",
+    "cohort_end_date", "flag", "flag_1"
+  ) == colnames(x)))
+  expect_true(x |> dplyr::pull("flag") |> unique() == 1)
+  expect_true(x |> dplyr::pull("flag_1") |> unique() == 0)
+  y <- addInObservation(cdm$cohort1, name = "flag_new")
+  expect_true(all(c(
+    "cohort_definition_id", "subject_id", "cohort_start_date",
+    "cohort_end_date", "flag", "flag_1", "flag_new"
+  ) == colnames(y)))
+  expect_true(y |> dplyr::pull("flag") |> unique() == 0)
+  expect_true(y |> dplyr::pull("flag_new") |> unique() == 1)
+  expect_true(y |> dplyr::pull("flag_1") |> unique() == 0)
 
-  expect_warning(x <- addInObservation(cdm$cohort1, cdm, name = "flag"))
-  expect_true(all(c("flag", "flag_1", "flag_2") %in% colnames(x)))
-  expect_true(all(c("flag", "flag_1", "flag_new") %in% colnames(addInObservation(cdm$cohort1, cdm, name = "flag_new"))))
 })
 
-
 test_that(" test checkWindow in addIntersect", {
   cdm <- mockPatientProfiles(connectionDetails, seed = 11, patient_size = 2)
 
-  expect_error(cdm$cohort1 %>% addIntersect(cdm, tableName = "cohort2", window = list(c(-NA, 0)), value = "date"))
-  expect_error(cdm$cohort1 %>% addIntersect(cdm, tableName = "cohort2", window = list(c(-365, 0, 1)), value = "date"))
-  expect_warning(cdm$cohort1 %>% addIntersect(cdm, tableName = "cohort2", window = list(c(-365), -c(0), -c(30)), value = "date"))
+  expect_error(cdm$cohort1 %>% addIntersect(tableName = "cohort2", window = list(c(-NA, 0)), value = "date"))
+  expect_error(cdm$cohort1 %>% addIntersect(tableName = "cohort2", window = list(c(-365, 0, 1)), value = "date"))
+  expect_warning(cdm$cohort1 %>% addIntersect(tableName = "cohort2", window = list(c(-365), -c(0), -c(30)), value = "date"))
 
-  expect_error(cdm$cohort1 %>% addIntersect(cdm, tableName = "cohort2", window = list(c(30, -365)), value = "date"))
-  expect_error(cdm$cohort1 %>% addIntersect(cdm, tableName = "cohort2", window = list(c(Inf, Inf)), value = "date"))
-  expect_error(cdm$cohort1 %>% addIntersect(cdm, tableName = "cohort2", window = list(c(-Inf, -Inf)), value = "date"))
+  expect_error(cdm$cohort1 %>% addIntersect(tableName = "cohort2", window = list(c(30, -365)), value = "date"))
+  expect_error(cdm$cohort1 %>% addIntersect(tableName = "cohort2", window = list(c(Inf, Inf)), value = "date"))
+  expect_error(cdm$cohort1 %>% addIntersect(tableName = "cohort2", window = list(c(-Inf, -Inf)), value = "date"))
 })
 
 test_that("test checkSnakeCase", {
@@ -186,10 +224,30 @@ test_that("checkNameStyle", {
     ),
   )
 
-  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
+  person <- dplyr::tibble(
+    person_id = c(1, 2),
+    gender_concept_id = 1,
+    year_of_birth = c(1980, 1950),
+    month_of_birth = 01,
+    day_of_birth = 01,
+    race_concept_id = 0,
+    ethnicity_concept_id = 0
+  )
+  op <- dplyr::tibble(
+    person_id = 1:2,
+    observation_period_id = 1:2,
+    observation_period_start_date = as.Date("2000-01-01"),
+    observation_period_end_date = as.Date("2030-01-01"),
+    period_type_concept_id = 0
+  )
+
+  cdm <- mockPatientProfiles(
+    connectionDetails = connectionDetails, cohort1 = cohort1, person = person,
+    observation_period = op, cohort2 = cohort2
+  )
 
   expect_true(all(c("count_all", "flag_all") %in% colnames(cdm$cohort1 %>% addIntersect(
-    cdm = cdm, tableName = "cohort2",
-    value = c("flag", "count"), nameStyle = "{value}_{id_name}"
+    tableName = "cohort2", value = c("flag", "count"),
+    nameStyle = "{value}_{id_name}"
   ))))
 })
